#include "keyboard.h"

//**********************************************************************
//                      DEFINICION DE FUNCIONES
//======================================================================
// FUNCION   : WORD getch()
// ACCION    : Realiza la lectura de un registro en el buffer del teclado
//             y devuelve el codigo ASCII de la tecla correspondiente.
// PARAMETROS: NADA
// DEVUELVE  : WORD -> codigo ASCII.
//
// NOTA: La lectura elimina al registro del buffer.
//----------------------------------------------------------------------
WORD getch()
{
  HANDLE teclado;            // Manipulador del buffer del teclado.
  DWORD  leidos;             // Cantidad de registros de teclado leidos.
  DWORD  i;                  // Variable contador del ciclo for.
  int    contador = 0;       // Contador de eventos.
  WORD   tecla=0;            // Variable para la tecla leida.
  INPUT_RECORD buffer[128];  // Vector de registros de entrada de teclado

  // Caputrar el standard input handle.
  teclado = GetStdHandle(STD_INPUT_HANDLE);

  // Ciclo de espera por el evento de tecla presionada
  while (contador++ <= 100)
  {
    // Esperar por un evento.
    ReadConsoleInput(teclado, // manipulador del buffer
                     buffer,  // buffer a leer
                     128,     // tamanio del buffer
                     &leidos  // cantidad de registros leidos
                    );

    // verificar los eventos en busca de eventos de teclado.
    for (i = 0; i < leidos; i++)
    {
      if(buffer[i].EventType==KEY_EVENT
         &&
         buffer[i].Event.KeyEvent.bKeyDown
        )
      {
        tecla = buffer[i].Event.KeyEvent.wVirtualKeyCode;
        if(tecla==TECLA_enie) tecla=165; // Adapta la tecla .
        return tecla;
      }
    }
  }
}

//======================================================================
// FUNCION   : bool availableKey()
// ACCION    : Informa si se hay un registro de teclado sin leer en el
//             buffer de entrada.
// PARAMETROS: NADA
// DEVUELVE  : bool -> "true" si hay registros sin leer, y "false" si no
//
// NOTA: No vacia el buffer.
//----------------------------------------------------------------------
int availableKey()
{
  HANDLE teclado;            // Manipulador del buffer del teclado.
  DWORD  leidos;             // Cantidad de registros de teclado leidos.
  DWORD  i;                  // Variable contador del ciclo for.
  int    contador = 0;       // Contador de eventos.
  INPUT_RECORD buffer[128];  // Vector de registros de entrada de teclado

  // Caputrar el standard input handle.
  teclado = GetStdHandle(STD_INPUT_HANDLE);

  // Ciclo de espera por el evento de tecla presionada
  while (contador++ <= 100)
  {
    // Esperar por un evento.
    PeekConsoleInput(teclado, // manipulador del buffer
                     buffer,  // buffer a leer
                     128,     // tamanio del buffer
                     &leidos  // cantidad de registros leidos
                    );

    // verificar los eventos en busca de eventos de teclado.
    for (i = 0; i < leidos; i++)
    {
      if(buffer[i].EventType==KEY_EVENT
         &&
         buffer[i].Event.KeyEvent.bKeyDown
        )
      {
        return 1;
      }
    }
  }
  return 0;
}

//*********************************************************************
///// FIN DE ARCHIVO //////////////////////////////////////////////////
